<?php
if (! class_exists('SLPTagalong_AJAX')) {
    require_once(SLPLUS_PLUGINDIR.'/include/base_class.ajax.php');


    /**
     * Holds the ajax-only code.
     *
     * This allows the main plugin to only include this file in AJAX mode
     * via the slp_init when DOING_AJAX is true.
	 *
	 * @property		SLPTagalong			$addon
	 * @property-read	Tagalong_Data		$data
     *
     * @package StoreLocatorPlus\Tagalong\AJAX
     * @author Lance Cleveland <lance@charlestonsw.com>
     * @copyright 2014 Charleston Software Associates, LLC
     */
    class SLPTagalong_AJAX extends SLP_BaseClass_AJAX {
	    public $addon;
	    private $data;

	    /**
	     * Add our specific AJAX hooks.
	     */
	    function add_ajax_hooks() {
		    $this->addon->createobject_Data();
		    $this->data = $this->addon->data;

		    add_filter( 'slp_location_filters_for_AJAX' , array($this,'filter_JSONP_SearchByCategory')       );
		    add_filter( 'slp_results_marker_data'       , array($this,'filter_SetMapMarkers'         )       );
		    add_action( 'slp_orderby_default' , array( $this , 'add_category_count_to_orderby') , 5 );
	    }

		/**
		 * Change the results order.
		 *
		 * Precedence is given to the order by category count option over all other extensions that came before it.
		 * This is enacted by placing the special category count clause as the first parameter of extend_OrderBy,
		 * and by setting the filter to a high priority (run last).
		 *
		 */
		function add_category_count_to_orderby() {
			if ( empty( $this->addon->options['ajax_orderby_catcount'] ) ) { return; }
			$this->slplus->database->extend_order_array( '('.$this->data->get_SQL('select_categorycount_for_location').') DESC ' );
		}

	    /**
	     * Add the category condition to the MySQL statement used to fetch locations with JSONP.
	     *
	     * @param string $currentFilters
	     * @return string
	     */
	    function filter_JSONP_SearchByCategory($currentFilters) {
		    if (   empty( $this->formdata        ) ) { return $currentFilters; }
			if ( ! isset( $this->formdata['cat'] ) ) { return $currentFilters; }
            if ( ! is_array( $this->formdata['cat'] ) && ( $this->formdata['cat'] <= 0 ) ) { return $currentFilters; }

            $this->addon->createobject_Data();

            // Single Category
            //
            if ( ! is_array( $this->formdata['cat'] ) ) {
                $sql_select_stores_in_cats = sprintf ( 'AND ' . $this->addon->data->get_SQL( 'where_location_has_category' ) , $this->formdata['cat'] );

            // Array Of Categories
            } else {
                $sql_select_stores_in_cats = '';
                foreach ( $this->formdata['cat'] as $term_id ) {
                    if ( $term_id > 0 ) {
                        $sql_select_stores_in_cats .= sprintf ( 'AND ' . $this->addon->data->get_SQL( 'where_location_has_category' ) , $term_id );
                    }
                }
            }

		    // Setup and clause to select stores by a specific category
		    //
		    return array_merge( $currentFilters , array( $sql_select_stores_in_cats ) );
	    }


	    /**
	     * Set custom map marker for this location.
	     *
	     * Add the icon marker and filters out any results that don't match the selected category.
	     *
	     * SLP Filter: slp_results_marker_data
	     *
	     * @param mixed[] $mapData
	     * @return mixed[]
	     */
	    function filter_SetMapMarkers($mapData) {
		    if (!ctype_digit($mapData['id'])) { return $mapData; }
		    $this->addon->set_LocationCategories();

		    // If we are looking for a specific category,
		    // check to see if it is assigned to this location
		    // Category searched for not in array, Skip this one.
		    //
		    //
		    $filterOut = isset($_POST['formflds']) && isset($_POST['formflds']['cat']) && ($_POST['formflds']['cat'] > 0);
		    if ($filterOut) {
			    $selectedCat = (int)$_POST['formflds']['cat'];
			    if ( ! in_array ( $selectedCat , $this->addon->current_location_categories ) ) { return array(); }
		    }

			// Category Count
			//
			$category_count = count( $this->addon->current_location_categories );

			// Category Details
			// If category details is enabled (on by default), return them in the AJAX string.
			//
			$category_names = array();
			foreach ($this->addon->current_location_categories as $term_id) {
				$category_info = $this->addon->get_TermWithTagalongData($term_id);
				$category_names[] = isset( $category_info['name'] ) ? $category_info['name'] : '';
			}

            /**
             * FILTER: slp_category_name_separator
             * Change the default ', ' separator used between category names.
             *
             * @param   string  the character string to be used between each category on the category name results output
             *
             * @return string   the character string to be used between each category on the category name results output
             */
			$category_name_separator = apply_filters( 'slp_category_name_separator' , ', ' );
			$category_names = implode( $category_name_separator , $category_names );

		    // Return our modified array
		    //
		    return array_merge(
			    $mapData,
			    array(
				    'attributes'      => $this->slplus->currentLocation->attributes   ,
				    'categories'      => $this->addon->current_location_categories    ,
					'category_count'  => $category_count  ,
					'category_names'  => $category_names,
				    'icon'            => $this->set_LocationMarker()                  ,
				    'iconarray'       => $this->addon->createstring_IconArray()       ,
			    )
		    );
	    }

	    /**
	     * Set the location marker based on categories.
	     */
	    private function set_LocationMarker() {

		    $locationMarker = '';

		    // Location Marker from Tagalong
		    //
		    if (
			    ( ! $this->slplus->is_CheckTrue( $this->addon->options['default_icons'] ) )         &&
			    ( count( $this->addon->current_location_categories ) > 0 )
		    ) {

			    $best_rank = 999999;
			    foreach ( $this->addon->current_location_categories as $term_id ) {
				    $category_details = $this->addon->get_TermWithTagalongData( $term_id );
				    if
				    (
						 ( (int)$category_details['rank'] < $best_rank )  &&
				        isset( $category_details['map-marker'] )
				    ) {
					    $best_rank = (int)$category_details['rank'];
					    $locationMarker = $category_details['map-marker'];
				    }
			    }

			// No category marker - use the default marker.
			//
		    } else {
			    $locationMarker = ( isset( $mapData['attributes']['marker'] ) ? $mapData['attributes']['marker'] : '' );
		    }
		    return $locationMarker;
	    }
    }
}