<?php
/**
 * Plugin Name: Store Locator Plus :: Tagalong
 * Plugin URI: https://www.storelocatorplus.com/product/slp4-tagalong/
 * Description: A premium add-on pack for Store Locator Plus that adds advanced location tagging features.
 * Author: Store Locator Plus
 * Author URI: https://www.storelocatorplus.com/
 * Requires at least: 3.8
 * Test up to : 4.5
 * Version: 4.4.03
 *
 * Text Domain: csa-slp-tagalong
 * Domain Path: /languages/
 */

// No direct access allowed outside WordPress
//
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Since this is an add-on for Store Locator Plus
// we only want to "get started" after all plugins are loaded.
//
// This allows us to check our dependencies knowing SLP
// should be loaded into the PHP stack by now.
//
// Concept Credits: @pippinsplugins, @ipstenu
// @see https://pippinsplugins.com/checking-dependent-plugin-active/
// @see https://make.wordpress.org/plugins/2015/06/05/policy-on-php-versions/
//
function SLPTagalong_loader() {
    $this_plugin_name = __( 'Store Locator Plus :: Tagalong', 'slp-tagalong' );
    $min_wp_version   = '4.4';

    // Requires SLP
    //
    if ( ! defined( 'SLPLUS_PLUGINDIR' ) ) {
        add_action(
            'admin_notices',
            create_function(
                '',
                "echo '<div class=\"error\"><p>" .
                sprintf(
                    __( '%s requires Store Locator Plus to function properly. ', 'slp-tagalong' ),
                    $this_plugin_name
                ) . '<br/>' .
                __( 'This plugin has been deactivated.', 'slp-tagalong' ) .
                __( 'Please install Store Locator Plus.', 'slp-tagalong' ) .
                "</p></div>';"
            )
        );
        include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
        deactivate_plugins( plugin_basename( __FILE__ ) );

        return;
    }

    // Requires WP Version 3.8+
    //
    global $wp_version;
    if ( version_compare( $wp_version, $min_wp_version, '<' ) ) {
        add_action(
            'admin_notices',
            create_function(
                '',
                "echo '<div class=\"error\"><p>" .
                sprintf(
                    __( '%s requires WordPress %s to function properly. ', 'slp-tagalong' ),
                    $this_plugin_name,
                    $min_wp_version
                ) .
                __( 'This plugin has been deactivated.', 'slp-tagalong' ) .
                __( 'Please upgrade WordPress.', 'slp-tagalong' ) .
                "</p></div>';"
            )
        );
        include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
        deactivate_plugins( plugin_basename( __FILE__ ) );

        return;
    }

    // Define some path constants in an attempt to bypass depth-driven confusion.
    //
    if ( ! defined( 'SLPTAG_REL_DIR' ) ) {
        define( 'SLPTAG_REL_DIR', plugin_basename( dirname( __FILE__ ) ) );
    }
    if ( ! defined( 'SLPTAG_FILE' ) ) {
        define( 'SLPTAG_FILE', __FILE__ );
    }

    // Go forth and sprout your tentacles...
    // Get some Store Locator Plus sauce.
    //
    require_once( 'include/class.slp-tagalong.php' );
    SLPTagalong::init();
}

add_action( 'plugins_loaded', 'SLPTagalong_loader' );
